import {
  Component,
  createEffect,
  For,
  onCleanup,
  Suspense,
} from 'solid-js';



import Trkseg from '../trkseg';
import VectorSource from 'ol/source/Vector';
import {
  createCachedSignal,
  destroyCachedSignal,
} from '../../workers/cached-signals';

interface Props {
  trkId: string;
  vectorSource: VectorSource;
  context: any;
}
export const Trk: Component<Props> = ({ vectorSource, trkId, context }) => {
  const params = {
    id: trkId,
    method: 'getTrk',
  };
  const trk = createCachedSignal(params);

  onCleanup(() => {
    console.log({ caller: 'Trk / onCleanup', trkId, trk: trk(), params });
    destroyCachedSignal(params);
  });

  createEffect(() => {
    console.log({ caller: 'Trk', vectorSource, trkId, trk: trk() });
  });

  return (
    // @ts-ignore
    <For each={trk() ? trk().trkseg || [] : []}>
      {(trksegId: string) => {
        console.log({ caller: 'Trk / loop', trksegId });
        return (
          <Suspense>
            <Trkseg
              vectorSource={vectorSource}
              trksegId={trksegId}
              context={{ ...context, trk, trkId }}
            />
          </Suspense>
        );
      }}
    </For>
  );
};

export default Trk;
